@@ -41,10 +41,13 @@ class Aggregator:
                 change_request, aggregator["name"], address
             )
 
-            if split_addr[1] == "www":
+            if "www" in split_addr:
                 split_addr[1] = "prima"
-
-            self._update_k8s_ingress_route(aggregator, split_addr[1], split_addr[2])
+                self._update_k8s_ingress_route(aggregator, split_addr[1], split_addr[2])
+            elif "evvivass" in split_addr:
+                self._update_k8s_ingress_route(aggregator, split_addr[1], split_addr[2])
+            else:
+                return
 
     def _handle_captainhook_response(self, request, aggregator, address):
         if request.status_code == 200:
