@@ -1,12 +1,12 @@
 # -*- encoding: utf-8 -*-
 import re
+import time
 from urllib.parse import urljoin
 
 from requests_toolbelt.sessions import BaseUrlSession
 from suite_py.lib.requests.auth import BearerAuth
 
 REGEX = r"([A-Za-z]+-[0-9]+)"
-URL = "https://prima-assicurazioni-spa.myjetbrains.com/youtrack/issue/"
 
 
 class YoutrackHandler:
@@ -41,7 +41,7 @@ class YoutrackHandler:
                 {
                     "name": "Deployed",
                     "$type": "SimpleIssueCustomField",
-                    "value": "Today",
+                    "value": time.time() * 1000,
                 }
             ]
         }
